<?php

namespace EasyVideoReviews;

if (!defined('ABSPATH')) exit;

/**
 * Elementor Widget Class
 */


if (!class_exists('\EasyVideoReviews\EVR_ElementorButtons')) {

    class EVR_ElementorButtons extends \Elementor\Widget_Base

    {

        public function get_name()
        {
            return 'evr-buttons';
        }

        public function get_title()
        {
            return esc_html__('Easy Video Reviews Button', 'easy-video-reviews');
        }

        public function get_icon()
        {
            return 'evr-logo-icon';
        }

        public function get_categories()
        {
            return ['general'];
        }

        protected function register_controls()
        {

            $this->start_controls_section(
                'section_content',
                [
                    'label' => __('Button', 'easy-video-reviews'),
                ]
            );

            $this->add_control(
                'button_label',
                [
                    'label' => __('Button Label', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'Record Review'
                ]
            );
             
            $this->add_control(
                'button_bg_color',
                [
                    'label' => __('Button Background Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'blue',
                ]
            );
            $this->add_control(
                'button_text_color',
                [
                    'label' => __('Button Text Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'white',
                ]
            );


            $this->add_control(
                'button_size',
                [
                    'label' => __('Size', 'plugin-name'),
                    'type' => 'slider',
                    'size_units' => ['px'],
                    'range' => [
                        'min' => 1,
                        'max' => 72,
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 20,
                    ], 
                ]
            );

            $this->add_control(
                'button_alignment',
                [
                    'label' => __('Button Alignment', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'left' => [
                            'title' => __('Left', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-alignleft',
                        ],
                        'center' => [
                            'title' => __('Center', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-aligncenter',
                        ],
                        'right' => [
                            'title' => __('Right', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-alignright',
                        ],
                    ],
                    'default' => 'center',
                ]
            );

            $evr_folders = [];
            
            $evr_remote_data = get_evr_remote_data();

            if($evr_remote_data &&  $evr_remote_data->data && $evr_remote_data->data->folders) {

                foreach($evr_remote_data->data->folders as $folder){
                    $evr_folders[$folder->id] = $folder->name;
                }

            } 

            $default = count($evr_folders) > 0 ? array_key_first($evr_folders) : 0;

            $evr_folders = [ 0 => 'Select Folder'] + $evr_folders; 

            $this->add_control(
                'folder',
                [
                    'label' => __('Save videos in', 'easy-video-reviews'),
                    'type' => 'select2',

                    'options' => $evr_folders,
                    'default' => $default,
                    'multiple' => false,
                ]
            );

            $this->end_controls_section();
        }


        protected function render()
        {
            $settings = $this->get_settings_for_display(); 

            $this->add_inline_editing_attributes('label', 'basic');  

            $button = '[recorder align="' . esc_attr($settings['button_alignment']) . '" size="' . esc_attr($settings['button_size']["size"]) . '" color="' . esc_html($settings['button_text_color']) . '" background="' . esc_html($settings['button_bg_color']) . '" folder="' . esc_html($settings['folder']) . '"]' . esc_html($settings['button_label']) . '[/recorder]';

            echo (is_admin()) ? wp_kses_post(do_shortcode($button)) : wp_kses_post($button);
        }

        public function get_keywords()
        {
            return ['evr', 'easy', 'video', 'review', 'reviews', 'testimonial', 'wppool'];
        }

    }
}
