<?php

/**
 * Admin Hooks Class
 * includes/admin/Hooks.php
 * @since 1.1.0 
 */

# Namespace
namespace EasyVideoReviews\Admin;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

# Main class 
class Hooks extends \EasyVideoReviews\Controller
{
    # Registers the hooks
    function register_hooks()
    {
        # Register action hooks
        add_action("admin_enqueue_scripts", [$this, 'admin_enqueue_scripts']);

        add_action("admin_menu", [$this, 'admin_menu']);

        add_action("admin_footer", [$this, 'admin_footer']);

        add_action('admin_notices', [$this, 'admin_notices']);

        // admin init 
        add_action('init', [$this, 'init_appsero']);
    }

    # Shows admin notice asking for review
    public function admin_notices()
    {
        # Show hide_review_notice 

        if ($this->get_transient('show_review_notice', 'show') !== 'hide' && $this->get_option('show_review_notice', 'show') !== 'hide') {
            $this->view('admin/notices/ask-for-review');
        }

        # Show hide_affiliate_notice

        if ($this->get_transient('show_affiliate_notice', 'show') !== 'hide' && $this->get_option('show_affiliate_notice', 'show') !== 'hide') {
            $this->view('admin/notices/ask-for-affiliate');
        }
    }


    # Loads assets for backend dashboard
    function admin_enqueue_scripts($hook)
    {
        $current_screen = get_current_screen();
        $isBlockEditor = method_exists($current_screen, 'is_block_editor') && $current_screen->is_block_editor();

        $current_page = "";
        try {
            $current_page = explode('-', $hook);
            $current_page = end($current_page);
        } catch (\Exception $e) {
            $current_page = "";
        }

        $admin_footer_script = [
            "ajax_url"      => admin_url('admin-ajax.php'),
            "server_url"    => $this->app->server(),
            "plugin_url"    => EVR_URL,
            "home_url"      => home_url(),
            "host"          => $this->host(),
            "nonce"         => wp_create_nonce('evr_admin'),
            'current_page'          => $current_page,
            'extensions'    => apply_filters('evr_extensions', []),
            'is_debug'      => apply_filters('evr_debug', false),
            'offer_data'    => [],
            // 'remote_data'   => $this->remote_data()
        ];
        # Conditional elements
        if ($this->has_access_token()) {
            $admin_footer_script['access_token']        = $this->get_access_token();
            $admin_footer_script['is_wc_installed']     = $this->is_wc_installed();
            $admin_footer_script['is_wc_active']        = $this->is_wc_active();
            $admin_footer_script['is_edd_installed']    = $this->is_edd_installed();
            $admin_footer_script['is_edd_active']       = $this->is_edd_active();
        } else {
            $admin_footer_script['prefill']     = [
                'email'         => get_option('admin_email', ''),
                'first_name'    => get_user_meta(get_current_user_id(), 'first_name', true),
                'last_name'     => get_user_meta(get_current_user_id(), 'last_name', true),
            ];
        }

        $admin_footer_script = apply_filters('evr_admin_localize_script', $admin_footer_script);

        wp_register_script('_evr_inline', '');
        wp_localize_script('_evr_inline', '_evr_admin', $admin_footer_script);
        wp_enqueue_script('_evr_inline');

        wp_enqueue_script('swal2', EVR_PUBLIC . 'js/sweetalert2.js', ["jquery"], microtime(), true);
        wp_enqueue_script('evr-events', EVR_PUBLIC . 'js/events.min.js', ["jquery"], microtime(), true);
        wp_enqueue_style('evr-notice', EVR_PUBLIC . 'css/notice.css');


        if ($isBlockEditor || in_array($hook, [
            'toplevel_page_easy-video-reviews',
            'easy-video-reviews_page_easy-video-reviews-settings',
            'easy-video-reviews_page_easy-video-reviews-billing',
            'easy-video-reviews_page_easy-video-reviews-tools',
            'easy-video-reviews_page_easy-video-reviews-integrations',
            'easy-video-reviews_page_easy-video-reviews-profile',
        ])) {

            wp_enqueue_style('evr-admin', EVR_PUBLIC . 'css/admin.min.css');
            wp_enqueue_script('evr-admin', EVR_PUBLIC . 'js/admin.min.js', ['jquery'], microtime(), true);
            wp_enqueue_editor();
        }
    }

    # admin menu
    function admin_menu()
    { 
 
        if ($this->has_access_token()) {

            # Dashboard template
            add_menu_page(__('Easy Video Reviews', 'easy-video-reviews'), __('Easy Video Reviews', 'easy-video-reviews'), 'edit_others_posts', 'easy-video-reviews', function () {

                

            }, EVR_PUBLIC . '/images/evr.svg');

            # Reviews template
            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Reviews', 'easy-video-reviews'), __('Reviews', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews', function () {
 
                $action = $this->input->action ?? null;
                if ($action) {
                    $this->render_action($action);
                }

                $this->view('admin/base', [
                    'page' => 'reviews/base'
                ]);
            });

            # Profile template
            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Profile', 'easy-video-reviews'), __('Profile', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews-profile', function () {

                $this->view('admin/base', [
                    'page' => 'profile/base'
                ]);
            });

            # Billing template

            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Billing', 'easy-video-reviews'), __('Billing', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews-billing', function () {
 
                $action = $this->input->action ?? null;
                if ($action) {
                    $this->render_action($action);
                }

                $this->view('admin/base', [
                    'page' => 'billing/base'
                ]);
            });

            # Integrations template
            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Integrations', 'easy-video-reviews'), __('Integrations', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews-integrations', function () {
 
                $this->view('admin/base', [
                    'page' => 'integrations/base'
                ]);
            });

            # Tools template
            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Tools', 'easy-video-reviews'), __('Tools', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews-tools', function ()  {
                 
                $this->view('admin/base', [
                    'page' => 'tools/base'
                ]);

            }, 998);

            # Settings template
            add_submenu_page('easy-video-reviews', __('Easy Video Reviews Settings', 'easy-video-reviews'), __('Settings', 'easy-video-reviews'),  'edit_others_posts', 'easy-video-reviews-settings', function () {
                 
                $this->view('admin/base', [
                    'page' => 'settings/base'
                ]);
            }, 999);

            if (!is_evr_pro()) {
                add_submenu_page('easy-video-reviews', __('Easy Video Reviews Pro', 'easy-video-reviews'), __('Upgrade <span class="awaiting-mod">Pro</span>', 'easy-video-reviews'),  'edit_others_posts', admin_url('admin.php?page=easy-video-reviews-billing#plans'), '');
            }
        } else {

            # Loads get started page if the user is NOT logged in EVR
            add_menu_page(__('Get Started With Easy Video Reviews', 'easy-video-reviews'), __('Easy Video Reviews', 'easy-video-reviews'), 'edit_others_posts', 'easy-video-reviews', function () {

                $action = $this->input->action ?? null;

                if ($action) {
                    $this->render_action($action);
                }

                $this->view('get-started/base');
            }, plugin_dir_url(EasyVideoReviews) . 'public/images/icon.png', 99);
        }
    }



    /**
     * Elementor before scripts add custom icon class 
     */
    function evr_elementor_before_enqueue_scripts()
    {
        echo '<style>';
        echo '
        .evr-logo-icon {
        width: 25px;
        height: 20px;
        display: inline-block;
        margin: auto;
        background-image: url(\'' . EVR_PUBLIC . 'images/evr.svg\') !important;
        background-size: 100%;
        }';
        echo '</style>';
    }

    function kses_filter_allowed_html($allowed, $context)
    {
        if (is_array($context)) {
            return $allowed;
        }

        if ($context === 'post') {
            $allowed['a']['data-*'] = true;
            $allowed['table']['data-*'] = true;
        }

        return $allowed;
    }


    # Init appsero client plugin 
    function init_appsero()
    {
        if (class_exists('\EasyVideoReviews\Appsero\Client')) {
            $client = new \EasyVideoReviews\Appsero\Client('98bea24e-5324-4ccf-932a-6f1c77b67ad6', 'Easy Video Reviews', EasyVideoReviews);
            $client->set_textdomain('easy-video-reviews');
            $client->insights()->init();
        }
    }

    # Admin footer script 

    function admin_footer()
    {
        evr_render('admin/other/admin_footer');
    }


    # Render action
    function render_action($action = '')
    { 

        switch ($action) {
            case 'password-reset':
            case 'verification':

                $token = $this->input->token ?? null; # sanitized in the controller

                if (!$token) {
                    $this->view('admin/other/message', [
                        'message' => __('Invalid token', 'easy-video-reviews'),
                        'type' => 'error'
                    ]);

                    break;
                }

                $email = $this->input->email ?? get_option('admin_email');

                $server = new \EasyVideoReviews\Client();

                try {
                    $response = $server->post('password/verify', [
                        'email' => $email,
                        'token' => $token
                    ]);
 
                } catch (\Exception $e) {
                    $this->view('admin/other/message', [
                        'message' => $e->getMessage() ?? __('Invalid token', 'easy-video-reviews'),
                        'type' => 'error'
                    ]);
                }


                if (!$response->success) {
                    $this->view('admin/other/message', [
                        'message' => $response->message ?? __('Invalid token', 'easy-video-reviews'),
                        'type' => 'error'
                    ]);

                    return;
                }

                $this->update_option('access_token', $response->user->token);


                if ($action === 'password-reset') {

                    $server->setAccessToken($response->user->token);

                    $sent = $server->post('password/send', [
                        'email' => $email,
                        'token' => $token
                    ]);

                    if ($sent->success == true) {
                        $this->view('admin/other/message', [
                            'message' => $sent->message ?? __('A temporary password has been sent to your email.', 'easy-video-reviews'),
                            'type' => 'success',
                            'dismiss' => true
                        ]);
                    } else {
                        $this->view('admin/other/message', [
                            'message' => $sent->message ?? __('Invalid token', 'easy-video-reviews'),
                            'type' => 'error'
                        ]);
                    }
                } else {
                    $this->view('admin/other/message', [
                        'message' => $response->message ?? __('Account verification complete!', 'easy-video-reviews'),
                        'type' => 'success',
                        'dismiss' => true
                    ]);
                }


                break;

            case 'subscription':

                $status = $this->input->status ?? null;

                if (!$status) {
                    $this->view('admin/other/message', [
                        'message' => __('Invalid status', 'easy-video-reviews'),
                        'type' => 'error'
                    ]);
                } else {
                    $this->view('admin/other/message', [
                        'message' => $status == 'success' ? __('Subscription successful!', 'easy-video-reviews') : __('Subscription failed!', 'easy-video-reviews'),
                        'type' => 'success',
                        'dismiss' => true
                    ]);
                } 
             break;

            default:
                break;
        }
    }
}

/**
 * Instantiate the class and register hooks
 */
(new Hooks())->register_hooks();
