<?php

/**
 * Class Client
 * includes/classes/Client.php
 * Handles the Client functionality
 * @since 1.3.8
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

/**
 * Class Client
 */

class Client extends Controller
{

    // access token
    protected $access_token = null;

    // REST API suffix for version
    protected $rest_api_suffix = 'wp-json/evr/v2/';

    # constructor
    function __construct()
    {
        parent::__construct();

        $this->access_token = $this->get_access_token();
    }

    function setAccessToken($token) {
        $this->access_token = $token;
    }

    // get url 
    protected function get_url($route = '')
    {
        return $this->server() . $this->rest_api_suffix . $route;
    }

    // request 
    protected function make_request($method = "GET", $route = '', $data = [])
    {
        $url = $this->get_url($route);
        $args = [
            'method' => $method,
            'headers' => [
                'Authorization' => 'Bearer ' . $this->access_token,
                'Content-Type' => 'application/json',
            ],
        ];

        if ($method == 'POST') {
            $args['body'] = json_encode($data);
        }

        if ($method == 'GET') {
            $url = add_query_arg($data, $url);
        }

        $response = wp_remote_request($url, $args);

        if (is_wp_error($response)) {
            throw new \Exception($response->get_error_message());
        }

        $body = wp_remote_retrieve_body($response);

        $body = json_decode($body);

        // response code 
        $response_code = wp_remote_retrieve_response_code($response);

        // is server down 
        if ($response_code >= 500) {
            return "Easy Video Reviews server is down. Please try again later.";
        }

        return $body;
    }

    # get request
    function get($route = '', $data = [])
    {
        return $this->make_request('GET', $route, $data);
    }

    # post request
    function post($route = '', $data = [])
    {
        return $this->make_request('POST', $route, $data);
    }

    # App information
    function app_information()
    {
        $response = $this->get('app', [
            'website' => $this->host()
        ]);

        if(is_string($response)) return $response;

        if(isset($response->success)) {
            return $response;
        }

        return false;    
    }
 
     
}
