<?php

/**
 * Class Adjustment
 * includes/classes/Adjustment.php
 * Adjusts user's preferences with latest changes
 * @since 1.3.0
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

/**
 * Class Adjustment
 */

class Hooks  extends \EasyVideoReviews\Controller
{ 
    # Register hooks
    public function init()
    {
        $this->add_actions();
        $this->add_filters();
    }

    # Add action hooks
    function add_actions()
    {
        # Regsiter action hooks  
        add_action("wp_enqueue_scripts", [$this, 'enqueue_scripts']);
        add_action("wp_footer", [$this, 'evr_add_script_wp_footer']); 
        add_action("template_redirect", [$this, 'template_redirect']); 

        add_filter("wp_kses_allowed_html", [$this, 'kses_filter_allowed_html'], 0, 10);

        if ($this->is_pro()) {
            add_action("woocommerce_thankyou", [$this, 'evr_woocommerce_thankyou'], 12);
            add_action("woocommerce_email_footer", [$this, 'evr_woocommerce_email_footer'], 0);
            add_action("edd_payment_receipt_after", [$this, 'evr_edd_add_review_button'], 12);
            add_action("edd_email_footer", [$this, 'evr_edd_email_footer'], 12);

            # Register filter hooks
            add_filter("woocommerce_product_tabs", [$this, 'evr_woocommerce_product_tabs'], 99);
        }
    }

    # Add filter hooks
    function add_filters()
    {}

    # Loads assets to frontend
    function enqueue_scripts()
    {

        # gets options value 

        # Frontend localized script
        $frontend_footer_script = [
            "server_url" => $this->app->server(),
            "ajax_url" => admin_url('admin-ajax.php'),
            "home_url" => home_url(),

            "host" => $this->host(),

            "access_token" => $this->get_access_token(),
            'preference' => $this->get_option('recorder'),
            "forms" => $this->get_option('forms'),
            "translations" => $this->get_option('translations'),
            "defaultShowcase" => $this->app->showcase_config(), 

            "debug" => boolVal($this->is_debug())
        ];

        wp_register_script('evr_options_scripts', '');
        wp_localize_script('evr_options_scripts', '_evr', apply_filters('evr_localize_script', $frontend_footer_script));
        wp_enqueue_script('evr_options_scripts');

        wp_enqueue_script('evr-frontend', plugin_dir_url(EasyVideoReviews) . 'public/js/app.min.js', ['jquery'], microtime(), true);
        wp_enqueue_style('evr-frontend', plugin_dir_url(EasyVideoReviews) . 'public/css/app.min.css', null, microtime());
    }

    # Loads recorder template to footer
    function evr_add_script_wp_footer()
    {
        evr_render('frontend/modal');
    }

    # On WooCommerce Single Product Tabs
    function evr_woocommerce_product_tabs($tabs)
    {
        $woo = get_evr_option('woocommerce');
        if ($woo->single_tab) {
            $tabs['evr_tab'] = array(
                'title'     => wp_sprintf('%s', $woo->single_tab_label),
                'priority'     => 50,
                'callback'     => [$this, 'evr_custom_data_tab_callback']
            );
        }


        if ($woo->single_tab_hide_default) {
            unset($tabs['reviews']);
        }

        return $tabs;
    }


    # WooCommerce Single Product Tabs Callback Function
    function evr_custom_data_tab_callback()
    {
        global $product;
        $folder = esc_attr("product-" . $product->get_id());

        $woo = get_evr_option('woocommerce');
        echo ('<div class="woocommerce">');
        if ($woo->single_button) {
            echo wp_kses_post(do_shortcode('[evr-button folder=' . $folder . '][/evr-button]'));
        }
        if ($woo->single_tab_showcase) {
            $output = '[evr-videos cols="3" view="grid" limit="' . esc_attr($woo->single_limits) . '" order="' . esc_attr($woo->single_order) . '" orderBy="' . esc_attr($woo->single_order_by) . '"  tag=' . esc_attr($tag) . '][/evr-videos]';
            echo wp_kses_post(do_shortcode($output));
        }
        echo '</div>';
    }

    # On WooCommerce Thank you Page
    function evr_woocommerce_thankyou($order_id)
    {
        $woo = get_evr_option('woocommerce');
        if (!$woo->order_complete_button) return false;
        echo wp_kses_post(do_shortcode('[evr-button tag=' . esc_attr('order-' . $order_id) . ']'));
    }
 
 
    # renders video review showcase
    function renderShowcase($atts, $content = null)
    {
        $attributes = $this->app->get_showcase_config();
        $attributes["columns"] = false;
        $atts = shortcode_atts($attributes, $atts, 'evr-videos');

        $cols = $atts['columns'] ?? $atts['columns'] ?? 4;

        $configs = [
            "id" => $atts['id'],
            "tag" => $atts['tag'] ?? '',
            "view" => $atts['view'] ?? 'grid',
            "limit" => $atts['limit'] ?? 9,
            "order" => $atts['order'] ?? 'DESC',
            "columns_mobile" => $atts['columns_mobile'] ?? 2,
            "columns_tablet" => $atts['columns_tablet'] ?? 3,
            "columns" => $cols,
            "columns" => $cols,
            "gap_mobile" => $atts['gap_mobile'] ?? 5,
            "gap_tablet" => $atts['gap_tablet'] ?? 10,
            "gap" => $atts['gap'] ?? 15,
            "pagination" => $atts['pagination'] ?? false,
            "navigation" => $atts['navigation'] ?? false,
            "scrollbar" => $atts['scrollbar'] ?? false,
            "infinity" => $atts['infinity'] ?? false,
            "autoplay" => $atts['autoplay'] ?? false,
            "delay" => $atts['delay'] ?? 3000,
            "date" => $atts['date'] ?? false,
            "folder" => $atts['folder'] ?? '',
            "folders_include" => $atts['in'] ?? '',
            "folders_exclude" => $atts['not_in'] ?? '',
        ];

        $showcase = ""; 


        if ($atts['view'] == 'slider') {

            $showcase = "<div class=\"swiper evr-swiper evr-reviews overflow-x-hidden relative\">
            <div class=\"swiper-wrapper\"  data-evr-reviews='" . json_encode($configs) . "'>
                <div class=\"swiper-slide\">
                    <div class=\"swiper-lazy-preloader\"></div>
                </div>
            </div>
            " . ($atts['pagination'] == '1' ? "<div class=\"swiper-pagination\"></div>" : "") . "
            " . ($atts['navigation'] == '1' ? " <div class=\"swiper-button-next\"></div>
            <div class=\"swiper-button-prev\"></div>" : "") . ($atts['scrollbar'] == '1' ?  "<div class=\"swiper-scrollbar\"></div>" : "") . "
        </div>";
        } else {

            $showcase = '<div class="evr-reviews relative grid lg:grid-cols-' . esc_attr($cols) . ' grid-cols-' . esc_attr($cols) . ' md:grid-cols-' . esc_attr($atts["columns_tablet"]) . ' sm:grid-cols-' . esc_attr($atts["columns_mobile"]) . ' gap-' . esc_attr($atts["gap"]) . ' md:gap-' . esc_attr($atts["gap_tablet"]) . ' sm:gap-' . esc_attr($atts["gap_mobile"]) . ' md:gap-3 lg:gap-4" data-evr-reviews=\'' . json_encode($configs) . '\'>
            <div class="swiper-lazy-preloader"></div></div>';
        }

        return $showcase;
    }


    #  Single page video page / player
    function template_redirect()
    {
        $single_review_page_id = $this->get_option("review_page_id");
        
        // check current page is in $custom_pages list
        $current_page_id = absint(get_queried_object_id());
 
        if (($current_page_id == $single_review_page_id)) {

            define('EVR_SINGLE_REVIEW', true);
            
            $this->view('frontend/single-review'); 
            exit();
        }

    }


    # On WooCommerce Thank you Page
    function build_dynamic_message($pre_text = '', $args = [])
    {
        $output = $pre_text;

        if ($args && !empty($args)) {
            foreach ($args as $arg => $value) {
                $output = preg_replace("/\{$arg\}/i", $value, $output);;
            }
        }

        return $output;
    }



    # Email message
    function get_email_append_message()
    {
        $email = get_evr_option('email');
        $recorder_page = get_evr_option('recorder_page');

        $url = get_permalink($recorder_page) . '?tag=orders&source=email';

        $message = $this->build_dynamic_message("<div style=\"padding-top:15px; font-family:\"Helvetica Neue\",Helvetica,Roboto,Arial,sans-serif;\"><div style=\"text-align: center;\">{$email->message}</div></div>", [
            'button' => "<div style=\"text-align:center; padding-top: 8px; margin-top: 5px; \">
        <a href=\"{$url}\" target=\"_blank\" style=\"background: {$email->button->bg}; color: {$email->button->color}; font-size: {$email->button->size}px; padding: 10px 12px; border-radius: 5px; text-decoration: none;\">
            {$email->button->text}
        </a>
    </div>"
        ]);

        return apply_filters('evr_thankyou_email_html', $message);
    }



    # WooCommerce Email footer
    function evr_woocommerce_email_footer($email)
    {
        if ($email->id != 'customer_completed_order') return false;
        $woo = get_evr_option('woocommerce');
        if (!$woo->order_complete_email) return false;

        echo wp_kses_post($this->get_email_append_message());
    }



    # Easy Digital Downloads Button after purchasing
    function evr_edd_add_review_button()
    {
        $edd_option = get_evr_option('edd');

        if (!$edd_option->order_complete_button) return false;
        echo wp_kses_post(do_shortcode('[evr-button tag="edd-review"]'));
    }



    # Easy Digital Downloads Email Footer
    function evr_edd_email_footer()
    {
        $edd_option = get_evr_option('edd');
        if (!$edd_option->order_complete_email) return false;

        echo wp_kses_post($this->get_email_append_message());
    }




    # Single Video Page Styles
    function add_styles_to_single_video_page()
    {
        if (!is_admin()) {
            wp_enqueue_style('evr_single_style', plugin_dir_url(EasyVideoReviews) . "public/css/frontend.css", [], null, false);
        }
    }




    # Single Video Page Scripts
    function add_scripts_to_single_video_page()
    {
        if (!is_admin()) {
            wp_enqueue_script('jquery');
            wp_enqueue_script('evr_single_sc ript', plugin_dir_url(EasyVideoReviews) . "public/js/frontend.js", [], null, false);
        }
    }

    function kses_filter_allowed_html($allowed, $context)
    {
        if (is_array($context)) {
            return $allowed;
        }

        if ($context === 'post') {
            $allowed['a']['data-*'] = true;
            $allowed['table']['data-*'] = true;
        }

        return $allowed;
    }
}

# Instance
(new Hooks()) -> init(); 
