<?php

/**
 * Class Review
 * includes/classes/Review.php
 * Render & load single review
 * @since 1.3.8
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

/**
 * Class Review
 */

class Review extends Controller
{
    # video query 
    public $query = null;

    # construct
    function __construct()
    {
        parent::__construct();
    }

    /**
     * Load a single review
     */
    function get()
    {
        $server = new Client();

        $args = [];
        
        if( isset( $this->input->id ) ){
            $args['id'] = $this->input->id;
        } elseif( isset( $this->input->v ) ) {
            $args['slug'] = $this->input->v;
        } else {
            return null;
        } 

        $args['website'] = $this->host();

        try {
            // Specific video id
            $response = $server->get(
                'public/reviews',
                $args
            );
        } catch (\Exception $e) {
            throw new \Exception("Invalid or inexistent video.");
        }
 

        if (!$response->success) {
            throw new \Exception($response->message ?? __('Sorry! We can not load your review right now. Please check back later!', 'easy-video-reviews'));
        }

        // return first element if array not empty 

        $result = $response->data;

        if ($response->data && is_array($response->data) && count($response->data) > 0) {
            $result = $response->data[0];
        }

        if(!$result) return false;
        
        $result = (object) $result;

        $result->headless = $this->input->headless ?? false;


        $result->page_url = get_permalink();
        if( array_key_exists('id', $args) ) {
            $result->page_url = get_permalink() . '?id=' . $args['id'];
        } elseif( array_key_exists('slug', $args) ) {
            $result->page_url = get_permalink() . '?v=' . $args['slug'];
        }

        $title = get_bloginfo( 'name' );

        // check if title found on meta 
        if( isset( $result->meta->title ) && !empty( $result->meta->title ) ){
            $title = $result->meta->title;
        }

        $result->page_title = $title;

        $description = get_bloginfo( 'description' );

        // check if description found on meta
        if( isset( $result->meta->description ) && !empty( $result->meta->description ) ){
            $description = $result->meta->description;
        }

        $result->page_description = $description;

        return (object) $result;
    }
}
