<?php

/**
 * Class Shortcode
 * includes/classes/Shortcodes.php
 * Handles the ShortCode functionality
 * @since 1.3.8
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

/**
 * Class Shortcode
 */

class Shortcode extends Controller
{
    # register the shortcode
    public function init()
    {
        add_shortcode('reviews', array($this, 'render_reviews_shortcode'));
        
        # as of 1.3.8
        add_shortcode('evr-videos', array($this, 'render_reviews_shortcode'));

        add_shortcode('recorder', array($this, 'render_recorder_shortcode')); 

        # as of 1.3.8
        add_shortcode('evr-button', array($this, 'render_recorder_shortcode'));
    }

    /**
     * Render the reviews shortcode
     * @param $atts
     * @return string
     */
    public function render_reviews_shortcode($atts = [])
    {
        $default_args = [
            // internal 
            'view' => 'grid',
            'date' => false,
            'rounded' => false,
            'shares' => false, 

            // slider 
            'autoplay' => false,
            'autoplay_speed' => 3000,
            'dots' => false,
            'arrows' => false,
            'infinite' => false,
            'slides_to_show' => 3,
            'slides_to_scroll' => 1,

            // sorting 
            'limit' => 10,
            'offset' => 0,
            'order' => 'DESC',
            'orderby' => 'id',
            'pagination' => false,
            'navigation' => false,

            // gird
            'columns' => 3,
            'columns_tablet' => 3,
            'columns_mobile' => 3, 
            'gap' => 10,
            'gap_tablet' => 10,
            'gap_mobile' => 10,

            // filters 
            'folder' => '',
            'folder_not' => '',
            'playlist' => '',
            'playlist_not' => '',
            'id' => '',
            'id_not' => '',
            'slug' => '',
            'slug_not' => '',
            'tags' => '',
            'tags_not' => '', 
        ];

        $args = shortcode_atts($default_args, $atts);  

        
        $configuration = json_encode($args );
 

        $showcase = ""; 

        if ($args['view'] == 'slider') {

            $showcase = "<div class=\"swiper evr-swiper evr-reviews overflow-x-hidden relative\">
            <div class=\"swiper-wrapper\"  data-evr-reviews=\"" . $configuration . "\">
                <div class=\"swiper-slide\">
                    <div class=\"swiper-lazy-preloader\"></div>
                </div>
            </div>
            " . ($args['pagination'] == '1' ? "<div class=\"swiper-pagination\"></div>" : "") . "
            " . ($args['navigation'] == '1' ? " <div class=\"swiper-button-next\"></div>
            <div class=\"swiper-button-prev\"></div>" : "") . ($args['scrollbar'] == '1' ?  "<div class=\"swiper-scrollbar\"></div>" : "") . "
        </div>";
        } else {

             $showcase = '<div class="evr-reviews relative grid lg:grid-cols-' . esc_attr($args['columns']) . ' grid-cols-' . esc_attr($args['columns']) . ' md:grid-cols-' . esc_attr($args["columns_tablet"]) . ' sm:grid-cols-' . esc_attr($args["columns_mobile"]) . ' gap-' . esc_attr($args["gap"]) . ' md:gap-' . esc_attr($args["gap_tablet"]) . ' sm:gap-' . esc_attr($args["gap_mobile"]) . ' md:gap-3 lg:gap-4" data-evr-reviews=\'' . json_encode($configuration) . '\'>
            <div class="swiper-lazy-preloader"></div></div>';
        }

        return $showcase;

    } 


    /**
     * Render the recorder shortcode
     * @param $atts
     * @return string
     */
    public function render_recorder_shortcode($atts = [], $content = null, $shortcode_tag = null)
    {
        $default_button = $this->get_option('default_button');

        $default_args = [
            // internal 
            'align' => $default_button->alignment ?? 'center',
            'display' => $default_button->display ?? 'block',
            'rounded' => $default_button->rounded ?? true, 
            'background' => $default_button->background ?? 'blue',
            'color' => $default_button->color ?? 'white',
            'size' => $default_button->size ?? 'auto',

            // filters 
            'folder' => 0,
            'playlist' => 0,
            'tags' => '',

            // accessability
            'dynamic' => false,
        ];

        $args = shortcode_atts($default_args, $atts); 

        if($args['dynamic'] == 1) {
            $params = (array) $this->input; # sanitized inputs

            if($params) {
                foreach($params as $key => $value) {
                    if(isset($args[$key])) {
                        $args[$key] = $value;
                    }
                }
            }

            if( $this->input->label ) {
                $content = $this->input->label; # sanitized inputs
            }
        } 

        if(isset($this->input->label) && !empty(isset($this->input->label))) {
            $content = $this->input->label;
        }

        if(empty($content)) $content = __("Leave a review", 'easy-video-reviews');

        $out = "<div class='text-{$args['align']} {$args['display']}'><span class='evr-recorder-button' style='color: {$args['color']}; background: {$args['background']}; font-size: {$args['size']}px' data-evr-button='" . esc_html($args['folder']) . "'>{$content}</span></div>";
        return $out;
    }
}

# Instantiate the class
$shortcode = new Shortcode();
$shortcode->init();