<?php

/**
 * Core App Class 
 * includes/core/App.php 
 * @since 1.0.0
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

# Main class 
class App
{ 
    # Get translation labels
    public function translations()
    {
        $texts = [
            'Start',
            'Upload review',
            'Record review',
            'You have no camera installed on your device or the device is currently being used by another application',
            'Please try visiting this page with a valid SSL certificate',
            "You can record up to %s minutes, don't worry you will review your video before sending",
            'Hide options',
            'Show options',
            'Delay',
            'No delay',
            'Seconds',
            'Choose camera',
            'Default camera',
            'Choose microphone',
            'Default microphone',
            'Save options',
            'Looks good, continue',
            'Upload video',
            "You can record up to %s minutes, don't worry you will review your video before sending",
            'Record',
            'Upload',
            'Uploading video...',
            'Record new video',
            "I'm allowing to publish this video",
            'Submit',
            'Record',
            'Start over',
            'Upload video',
            'Drag your files here or click in this area',
            'Continue',
            'Record video',
            'Uploaded Successfully!',
            'Video Duration Limit Exceeded, Select other file',
            'Please select a file less than %s',
            'Error attempting to enable full-screen mode: %s',
        ];

        $newArray = [];
        foreach ($texts as $text) {
            $newArray[$text] = $text;
        }

        return apply_filters('evr_translations', $newArray);
    } 
    /**
     * Get EVR Registered Options 
     */

    public function options()
    {
        $options = [
            'recorder' => [
                'max_video_length' => 120,
                'max_video_size' => 1000,
                'allow_upload' => 0,
                'show_publish_policy' => 0,
                'show_options' => 0,
                'show_form' => 0,
                'enable_delay' => true,
                'delay' => 3,
                'auto_publish' => true
            ],
            'default_button' => [
                'text' => __('Leave a video review', 'easy-video-reviews'),
                'color' => '#f0f0f0',
                'background' => '#000099',
                'size' => '18',
                'alignment' => 'center',
                'custom_css' => ''
            ],
            'email_template' => [
                'message' => __('If you like the product, please leave a video review for us {button}', 'easy-video-reviews'),
                'button' => [
                    'text' => __('Leave a video review', 'easy-video-reviews'),
                    'color' => '#f0f0f0',
                    'background' => '#000099',
                    'size' => '18',
                    'alignment' => 'center',
                    'custom_css' => ''
                ],
                'url' => [
                    'label' => __('Leave a video review', 'easy-video-reviews')
                ]
            ],
           
            'recording_page_id' => '',
            'review_page_id' => '',
            'forms' => [],
            'translations' => $this->translations()
        ];

        return apply_filters('evr_options', $options);
    }
     

    /**
     * Default Showcase Configuration
     */
    public static function showcase_config()
    {
        $configs = [
            "id" => "",
            "view" => "grid",
            "limit" => 9,
            "order" => "DESC",
            "columns_mobile" => 1,
            "columns_tablet" => 2,
            "columns" => 3,
            "gap_mobile" => 2,
            "gap_tablet" => 4,
            "gap" => 6,
            "pagination" => 0,
            "navigation" => 1,
            "scrollbar" => 0,
            "infinity" => 1,
            "autoplay" => 1,
            "delay" => 5000,
            "rounded" => true,
            "date" => false,
            "folder" => "",
            "in" => "",
            "not_in" => "",
        ];

        return apply_filters("evr_showcase_default_config", $configs);
    }


    /**
     * Get remote url 
     */

    public static function server()
    {
        return apply_filters("evr_server", 'https://evr.wppool.dev/');
    }

    /**
     * Get website host
     */

    public static function host()
    {
        return apply_filters("evr_host", $_SERVER['HTTP_HOST']);
    }

    /**
     * Get folders from remote url
     */

    public static function folders()
    {
        $url = self::server() . 'wp-json/evr/v2/folders?&website=' . self::host();
        $token =  get_evr_option('token');
        $headers = array(
            'Authorization' => 'Bearer ' . $token
        );

        try {
            $response = wp_remote_get($url, ['headers' => $headers]);
            $body = wp_remote_retrieve_body($response);
            $body = json_decode($body);

            // var_dump($body );

            $folders =  [
                'all' => __('All', 'easy-video-reviews'),
                '0' => __('Uncategorized', 'easy-video-reviews'),
            ];

            if ($body && $body->folders && is_array($body->folders)) {
                foreach ($body->folders as $folder) {
                    $folders[$folder->id] = $folder->name;
                }
            }


            return $folders;
        } catch (\Exception $e) {
            return [];
        }
    }
 
}
