<?php

/**
 * Base Extension Class
 * includes/core/Extension.php
 * @since 1.3.8
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

# Main class 
abstract class Extension extends \EasyVideoReviews\Controller
{

    public function add_extension($extensions)
    {
        $extensions[] = $this->get_settings();
        return $extensions;
    }

    public function add_options($options)
    {
        $options[$this->get_id()] = $this->options();
        return $options;
    }

    public function get_settings()
    {
        return apply_filters('evr_extension_settings', [
            'id' => $this->get_id(),
            'name' => $this->name(),
            'icon' => $this->icon(),
            'icon_url' => $this->icon_url(),
            'is_pro' => $this->is_pro()
        ], 99);
    }

    public function options()
    {
        return [];
    }

    public function render_extension_form()
    {
?>
        <section v-if="isScreen('<?php echo $this->id(); ?>')">
            <?php $this->form(); ?>
        </section>
<?php

    }

    static public function init()
    {
        $instance = new static;
        add_filter('evr_extensions', [$instance, 'add_extension'], 99);
        add_filter('evr_options', [$instance, 'add_options'], 99);
        add_filter('evr_admin_localize_script', [$instance, 'add_script'], 99);
        add_action('evr_extension_form', [$instance, 'render_extension_form'], 99);
    }

    protected function get_id()
    {
        return sanitize_title($this->id());
    }

    public function id()
    {
        return sanitize_title($this->name());
    }

    public function name()
    {
        return __('Example Extension');
    }

    public function form()
    {
        echo '';
    }

    public function icon()
    {
        return '';
    }

    public function icon_url()
    {
        return '';
    }

    public function is_pro()
    {
        return true;
    }

    public function script()
    {
        return false;
    }

    public function add_script($script)
    {
        if ($this->script()) $script[$this->get_id()] = $this->script();
        return $script;
    }
}
