<?php

/**
 * Procedural functions for Easy Video Reviews
 */

# Exit if accessed directly
defined('ABSPATH') or die('NOT ALLOWED');

# Custom EVR Defined function for Easy Video Reviews
if (!function_exists('get_evr_option')) {
    function get_evr_option($key = false, $default = null)
    {
        if (!$key) return false;
        $value = get_option('evr_' . $key);
        if ($value) {
            try {
                return json_decode(json_encode(maybe_unserialize($value)));
            } catch (\Exception $e) {
                return $value;
            }
        }
        return $default;
    }
}


# Detects if user logged into Easy Video Reviews account
if (!function_exists('is_evr_logged_in')) {
    function is_evr_logged_in()
    {
        return get_evr_option('token') == true;
    }
}

# Detects if user has pro access to Easy Video Reviews account
if (!function_exists('is_evr_pro')) {
    function is_evr_pro()
    {
        return get_evr_option('is_pro') == 1;
    }
}


# Renders Easy Video Reviews templates
if (!function_exists('evr_render')) {
    function evr_render($template_name = 'admin/base', $args = null, $once = true)
    {
        $template_name = trim($template_name, '/');
        if (file_exists(EVR_TEMPLATES . $template_name . '.php')) {
            if ($args && is_array($args) && !empty($args)) extract($args);
            if ($once !== false) include_once EVR_TEMPLATES . $template_name . '.php';
            else include EVR_TEMPLATES . $template_name . '.php';
        }
    }
}


# get Easy Video Reviews current version number
if (!function_exists('get_evr_version')) {
    function get_evr_version()
    {
        return get_evr_option('version', '1.0.0');
    }
}



# Render top navigation 

if (!function_exists('evr_navigation')) {
    function evr_navigation($args = [])
    {

        $items = isset($args['items']) ? $args['items'] : false;

        if (empty($items)) return false;

        evr_render('admin/other/top-navigation', [
            'items' => $items,
            'args' => $args,
        ]);
    }
}

# evr_log 
if (!function_exists('evr_log')) {
    function evr_log()
    {
        if (!class_exists('\EVR_Dev_Tool')) return false;
        $args = func_get_args();
        $user_name = get_current_user();
        // $user_name = $user->user_login;

        \EVR_Dev_Tool::log($args, $user_name);
    }
}



// get_evr_remote_data
if (!function_exists('get_evr_remote_data')) {

    function get_evr_remote_data()
    {
        global $evr_remote_data;

        if ($evr_remote_data) {
            return $evr_remote_data;
        }

        $client = new \EasyVideoReviews\Client();

        global $evr_remote_data;

        $app_information = $client->app_information();

        if ($app_information) {
            $evr_remote_data = $app_information;
            return $app_information;
        }

        return false;
    }
}
