<?php

/**
 * Helper Trait
 * includes/helper/Helper.php
 * @since 1.3.8
 */

# Namespace
namespace EasyVideoReviews;

# Exit if accessed directly
defined('ABSPATH') or die('Direct Script not Allowed');

# Main class 
trait Helper
{  
    # debug log
    function debug_log($data = null)
    {
        $log_file = EVRSaaS_PATH . '/logs.json';

        if (!file_exists($log_file)) {
            file_put_contents($log_file, '');
        }

        $log_json = file_get_contents($log_file);
        $log = json_decode($log_json, true);

        if (!$log) {
            $log = [];
        }

        $log[] = [
            'time' => time(),
            'data' => $data,
            'by' => get_current_user_id(),
        ];

        file_put_contents($log_file, json_encode($log));

        return true;
    }

    # is debug 
    function is_debug()
    {
        return class_exists('\EVR_Dev_Tool');
    }
 
    # is WooCommerce installed
    function is_wc_installed()
    {
        return class_exists('WooCommerce');
    }

    # is WooCommerce active
    function is_wc_active()
    {
        return in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')));
    }

    # is EasyDigitalDownloads installed
    function is_edd_installed()
    {
        return class_exists('Easy_Digital_Downloads');
    }

    # is EasyDigitalDownloads active
    function is_edd_active()
    {
        return in_array('easy-digital-downloads/easy-digital-downloads.php', apply_filters('active_plugins', get_option('active_plugins')));
    }

    # is Elementor active
    function is_elementor_active()
    {
        return in_array('elementor/elementor.php', apply_filters('active_plugins', get_option('active_plugins')));
    } 
}
